@@ -43,7 +43,7 @@ Test::CVE - Test against known CVE's
 use 5.014000;
 use warnings;
 
-our $VERSION = "0.10";
+our $VERSION = "0.11";
 
 use version;
 use Carp;
@@ -52,7 +52,7 @@ use Text::Wrap;
 use JSON::MaybeXS;
 use Module::CoreList;
 use YAML::PP     ();
-use List::Util qw( first );
+use List::Util qw( first uniq );
 use base       qw( Test::Builder::Module );
 
 use parent "Exporter";
@@ -86,6 +86,7 @@ sub new {
     $self{make_pl}  ||= "Makefile.PL";
     $self{build_pl} ||= "Build.PL";
     $self{CVE}        = {};
+    ref $self{want} or $self{want} = [ $self{want} ]; # new->(want => "Foo")
     my $obj = bless \%self => $class;
     $obj->skip ($self{skip} // "CVE.SKIP");
     return $obj;
@@ -372,6 +373,8 @@ sub test {
 
     $self->{j}{db}{$rel} and unshift @{$self->{want}} => $rel;
 
+    $self->{want} = [ uniq @{$self->{want}} ];
+
     my @w = @{$self->{want}} or return $self; # Nothing to report
 
     foreach my $m (@w) {
@@ -486,11 +489,40 @@ sub cve {
     } # cve
 
 sub has_no_cves {
+    my %attr = @_;
+    my $tb = __PACKAGE__->builder;
+
+    # By default skip this test is not in a development env
+    if (!exists $attr{author} and
+	 ((caller)[1] =~ m{(?:^|/)xt/[^/]+\.t$} or
+	  $ENV{AUTHOR_TESTING}                  or
+	  -d ".git" && $^X =~ m{/perl$})) {
+	$attr{author}++;
+	}
+    unless ($attr{author}) {
+	$tb->ok (1, "CVE tests skipped: no author environment");
+	return;
+	}
+
+    $attr{perl} //= 0;
+
     my $cve = Test::CVE->new (@_);
     $cve->test;
     my @cve = $cve->cve;
-    my $tb = __PACKAGE__->builder;
-    $tb->ok (@cve == 0, "This release found no open CVEs");
+    if (@cve) {
+	$tb->ok (0, "This release found open CVEs");
+	foreach my $r (@cve) {
+	    my ($m, $v) = ($r->{release}, $r->{vsn});
+	    foreach my $c (@{$r->{cve}}) {
+		my $cve = join ", "  => @{$c->{cve}};
+		my $av  = join " & " => @{$c->{av}};
+		$tb->diag (0, "$m-$v : $cve for $av");
+		}
+	    }
+	}
+    else {
+	$tb->ok (1, "This release found no open CVEs");
+	}
     } # has_no_cves
 
 1;
@@ -711,6 +743,10 @@ Severity. Most entries doe not have a severity
 
 =head3 has_no_cves
 
+Note upfront: You most likely do B<NOT> want this in a test-suite, as
+making the test suite C<FAIL> on something the end-user is incapable
+of fixing might not be a friendly approach.
+
  use Test::More;
  use Test::CVE;
 
@@ -720,14 +756,22 @@ Severity. Most entries doe not have a severity
 Will return C<ok> is no open CVE's are detected for the current build
 environment.
 
-C<has_no_cves> will accept all arguments that C<new> accepts.
+C<has_no_cves> will accept all arguments that C<new> accepts plus one
+additional: C<author>. The C<perl> attribute defaults to C<0>.
 
  has_no_cves (@args);
 
-is identical to
+is more or less the same as
 
- my @cve = @{Test::CVE->new (@args)->test-cve // []};
+ my @cve = Test::CVE->new (@args)->test->cve;
  ok (@cve == 0, "This release found no open CVEs");
+ diag ("...") for map { ... } @cve;
+
+By default, C<has_no_cves> will only run in a development environment,
+but you can control that with the C<author> attribute. When not passed,
+it will default to C<1> if either the test unit is run from the C<xt/>
+folder or if filder C<.git> exists and the invoking perl has no version
+extension in its name, or if C<AUTHOR_TESTING> has a true value.
 
 =head1 TODO and IDEAS
 
